import styled, { css } from "styled-components";
import { FaCross as Cross } from "react-icons/fa";
import { FaBook as BookContent } from "react-icons/fa";

const openTocDiv = css`
  background: ${(props) => props.theme.background};
  color: ${(props) => props.theme.textColor};
  padding: 0.7em 1.2em;
  border-radius: 0.5em;
  box-shadow: 0 0 1em rgba(0, 0, 0, 0.5);
  border: 1px solid ${(props) => props.theme.borderColor};
`;

export const TocDiv = styled.div`
  height: max-content;
  max-height: 80vh;
  overflow-y: scroll;
  z-index: 1;
  line-height: 2.2em;
  -webkit-overflow-scrolling: touch;

  @media screen and (max-width: 1024px) {
    max-width: 16em;
    position: fixed;
    bottom: 1em;
    left: 1em;
    ${(props) => !props.open && `height: 0;`};
    ${(props) => props.open && openTocDiv};
    visibility: ${(props) => (props.open ? `visible` : `hidden`)};
    opacity: ${(props) => (props.open ? 1 : 0)};
    transition: 0.3ms all ease-in-out;
  }

  @media screen and (min-width: 1024px) {
    max-width: 15em;
    font-size: 0.85em;
    grid-column: 4 / -1;
    position: sticky;
    top: 2em;
    right: 2em;
  }
`;

export const Title = styled.h2`
  margin: 0;
  padding-bottom: 0.5em;
  display: grid;
  grid-auto-flow: column;
  align-items: center;
  grid-template-columns: auto auto 1fr;
`;

export const TocLink = styled.a`
  color: ${({ theme, active }) => (active ? "red" : "grey")};
  display: block;
  margin-left: ${(props) => props.depth + `em`};
  border-top: ${(props) => props.depth === 0 && `1px solid grey `};
`;

export const TocIcon = styled(BookContent)`
  width: 1em;
  margin-right: 0.2em;
`;

const openerCss = css`
  position: fixed;
  bottom: 1em;
  left: 0;
  padding: 0.5em 0.6em 0.5em 0.3em;
  background: ${(props) => props.theme.background};
  z-index: 1;
  box-shadow: 0 0 1em ${(props) => props.theme.shadowColor};
  border: 1px solid ${(props) => props.theme.borderColor};
  border-radius: 0 50% 50% 0;
  transform: translate(${(props) => (props.open ? `-100%` : 0)});
`;

const closerCss = css`
  margin-left: 1em;
  border: 1px solid ${(props) => props.theme.borderColor};
  border-radius: 50%;
`;

export const Toggle = styled(Cross).attrs((props) => ({
  as: props.opener && BookContent,
  size: props.size || `1.2em`,
}))`
  transition: 0.3ms all ease-in-out;
  justify-self: end;
  :hover {
    transform: scale(1.1);
  }
  @media screen and (min-width: 1024px) {
    display: none;
  }
  ${(props) => (props.opener ? openerCss : closerCss)};
`;
